src.MEDS\_tabular\_automl.configs
=================================

.. automodule:: src.MEDS_tabular_automl.configs



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   src.MEDS_tabular_automl.configs.tabularization
